@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 import typing as t
+
 from uuid import uuid4
 
 import aiosqlite
@@ -101,6 +102,12 @@ class Backend(ABCDatabaseBackend):
     db_type = 'sqlite'
     connection_cls = Connection
 
+    def __init__(self, url, isolation_level: str = None, **kwargs):
+        """Set a default isolation level (enable autocommit). Fix in memory URL."""
+        if url.netloc == ':memory:':
+            url = url._replace(path=':memory:')._replace(netloc='')
+        super(Backend, self).__init__(url, isolation_level=isolation_level, **kwargs)
+
     async def connect(self) -> None:
         pass
 
@@ -108,9 +115,8 @@ class Backend(ABCDatabaseBackend):
         pass
 
     async def acquire(self) -> aiosqlite.Connection:
-        conn = aiosqlite.connect(database=self.url.netloc, isolation_level=None, **self.options)
-        await conn.__aenter__()
-        return conn
+        return await aiosqlite.connect(database=self.url.path, **self.options)
 
-    async def release(self, conn: aiosqlite.Connection) -> None:
-        await conn.__aexit__(None, None, None)
+    async def release(self, conn: aiosqlite.Connection):
+        await conn.commit()
+        await conn.close()
